package com.engage.zapier;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.EnableAutoConfiguration;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.cache.annotation.EnableCaching;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;

import com.engage.zapier.constant.ServiceConstant;
import com.engage.zapier.controller.ZapierController;
import com.engage.zapier.entity.common.MasterDataEntity;
import com.engage.zapier.repository.common.MasterDataRepository;
import com.engage.zapier.utility.MasterDataForStandardFields;

@EnableCaching
@SpringBootApplication
@EnableAutoConfiguration
@ComponentScan(
	    basePackages = {"com.engage.zapier", "com.engage.zapier.service",
	        "com.engage.zapier.utility"},
	    basePackageClasses = {ZapierController.class})
public class ZapierApplication {

	public static void main(String[] args) {
		SpringApplication.run(ZapierApplication.class, args);
	}

	@Bean
	CommandLineRunner init(MasterDataRepository masterDataRepository,
			MasterDataForStandardFields masterDataTypemasterDataType) {
		return args -> {
			List<String> dataTypes = Arrays.asList(ServiceConstant.MASTER_DATA_TYPE_LEAD_STATUS,
					ServiceConstant.MASTER_DATA_TYPE_LEAD_TYPE, ServiceConstant.MASTER_DATA_TYPE_LEAD_SOURCE,
					ServiceConstant.MASTER_DATA_TYPE_LEAD_TITLE, ServiceConstant.MASTER_DATA_TYPE_LEAD_RATING,
					ServiceConstant.MASTER_DATA_TYPE_LEAD_INDUSTRY,
					ServiceConstant.MASTER_DATA_TYPE_LEAD_UNQUALIFIED_REASON);
			Map<String, List<MasterDataEntity>> map = new HashMap<>();
			dataTypes.forEach(masterDataType -> {
				map.put(masterDataType, masterDataRepository.findByDataType(masterDataType));
				masterDataTypemasterDataType.setMasterDataFieldValueMap(map);
			});
		};

	}
}
