package com.engage.zapier.aop;

import java.util.Arrays;

import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.After;
import org.aspectj.lang.annotation.AfterReturning;
import org.aspectj.lang.annotation.AfterThrowing;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.reflect.MethodSignature;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;
import org.springframework.util.StopWatch;

/**
 * 
 * @author sajidshaikh
 *
 */

@Aspect
@Component
public class LoggingAspect {
	private static final Logger LOGGER = LoggerFactory.getLogger(LoggingAspect.class);
	private static final String CLASSNAME = LoggingAspect.class.getName();

	// AOP expression for which methods shall be intercepted
	@Around("execution(* com.connect..*(..)))")
	public Object profileAllMethods(ProceedingJoinPoint proceedingJoinPoint) throws Throwable {
		MethodSignature methodSignature = (MethodSignature) proceedingJoinPoint.getSignature();

		// Get intercepted method details
		String methodName = methodSignature.getName();

		final StopWatch stopWatch = new StopWatch();

		// Measure method execution time
		stopWatch.start();
		Object result = proceedingJoinPoint.proceed();
		stopWatch.stop();

		// Log method execution time
		LOGGER.info("Execution time of :{}:{}:{} :{}",CLASSNAME,methodName,stopWatch.getTotalTimeMillis()," ms");
		return result;
	}

	@AfterReturning(value = "execution(* com.engage.zapier..*.*(..))", returning = "result")
	public void afterReturning(JoinPoint joinPoint, Object result) {
		LOGGER.info("{} returned with value {}", joinPoint, result);
	}

	@After(value = "execution(* com.engage.zapier..*.*(..))")
	public void after(JoinPoint joinPoint) {
		LOGGER.info("after execution of {}", joinPoint);
	}

	@Before("execution(* com.engage.zapier..*.*(..))")
	public void before(JoinPoint joinPoint) {
		LOGGER.info("before execution of {}", joinPoint);
	}

	@AfterThrowing(pointcut = "execution(* com.engage.zapier..*.*(..))", throwing = "ex")
	public void doRecoveryActions(JoinPoint joinPoint, Throwable ex) {
		String methodName = joinPoint.getSignature().getName();
		String stuff = joinPoint.getSignature().toString();
		String arguments = Arrays.toString(joinPoint.getArgs());
		LOGGER.info("We have caught exception in method:{}, with arguments :{},\nand the full toString:{},\nthe exception is :{}",methodName,arguments,stuff,ex.getMessage());
	}

}