package com.engage.zapier.config;

import java.sql.Connection;
import java.sql.SQLException;

import javax.sql.DataSource;

import org.hibernate.HibernateException;
import org.hibernate.engine.jdbc.connections.spi.MultiTenantConnectionProvider;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class MultiTenantConnectionProviderImpl implements MultiTenantConnectionProvider {
	
	private static final long serialVersionUID = -7528165788244921758L;
	
	private static final Logger LOGGER = LoggerFactory.getLogger(MultiTenantConnectionProviderImpl.class);
	private static final String CLASSNAME = MultiTenantConnectionProviderImpl.class.getName();

	private static final String USE_DATABASE = "USE ";

    @Autowired
    private DataSource commonDataSource;

    public MultiTenantConnectionProviderImpl(DataSource commonDataSource) {
        this.commonDataSource = commonDataSource;
    }

    @Override
    public Connection getAnyConnection() throws SQLException {
        return commonDataSource.getConnection();
    }

    @Override
    public void releaseAnyConnection(Connection connection) throws SQLException {
        connection.close();
    }

    @Override
    public Connection getConnection(String tenantIdentifier) throws SQLException {

    	LOGGER.debug("Get connection for tenant {}", tenantIdentifier);
        final Connection connection = getAnyConnection();
        try {
            if(tenantIdentifier != null) {
                connection.createStatement().execute(USE_DATABASE + tenantIdentifier);
            } else {
                connection.createStatement().execute(USE_DATABASE + TenantContext.DEFAULT_TENANT);
            }
        } catch(SQLException exception) {
        	LOGGER.error("Error occurred in " + CLASSNAME + ".getConnection() on setting schema {}, Exception {}", tenantIdentifier, exception.getMessage());
            throw new HibernateException("Error occurred on getConnection: " + tenantIdentifier, exception);
        }
        return connection;
    }

    @Override
    public void releaseConnection(String tenantIdentifier, Connection connection) throws SQLException {
    	LOGGER.debug("Release connection for tenant {}", tenantIdentifier);
        try {
            connection.createStatement().execute(USE_DATABASE + TenantContext.DEFAULT_TENANT);
        } catch(SQLException exception) {
        	LOGGER.error("Error occurred in " + CLASSNAME + ".releaseConnection() on setting schema {}, Exception {}", tenantIdentifier, exception.getMessage());
            throw new HibernateException("Error occurred on releaseConnection " + tenantIdentifier, exception);
        }
        connection.close();
    }

    @Override
    public boolean supportsAggressiveRelease() {
        return false;
    }

    @SuppressWarnings("rawtypes")
    @Override
    public boolean isUnwrappableAs(Class unwrapType) {
        return false;
    }

    @Override
    public <T> T unwrap(Class<T> unwrapType) {
        return null;
    }
}