package com.engage.zapier.config;

import java.util.Optional;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import com.engage.zapier.entity.common.UserEntity;
import com.engage.zapier.entity.master.DataSourceMappingEntity;
import com.engage.zapier.entity.master.OauthTokenDetailsEntity;
import com.engage.zapier.repository.common.UserRepository;
import com.engage.zapier.repository.master.DataSourceMappingRepository;
import com.engage.zapier.request.utility.DESedeEncryption;
import com.engage.zapier.service.UserMasterService;

@Component
public class TenantInterceptor implements HandlerInterceptor {

	private static final Logger LOGGER = LoggerFactory.getLogger(TenantInterceptor.class);

	@Autowired
	private DataSourceMappingRepository dbMappingService;

	@Autowired
	private UserRepository userRepository;

	@Autowired
	private UserMasterService userMasterService;

	@Override
	public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler)
			throws Exception {
		if (StringUtils.isEmpty(request.getHeader("dsmId"))) {
			response.setStatus(HttpStatus.NOT_ACCEPTABLE.value());
			response.setContentType(MediaType.APPLICATION_JSON_VALUE);
			response.getWriter().write("{\"error\": \"please provide valid dsmId \"}");
			response.getWriter().flush();
			return false;

		}
		final String authorizationHeaderValue = request.getHeader("Authorization");
		if(StringUtils.isEmpty(authorizationHeaderValue)) {
			response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
			response.setContentType(MediaType.APPLICATION_JSON_VALUE);
			response.getWriter().write("Access token is empty");
			response.getWriter().flush();
			return false;
		}
		if (null != authorizationHeaderValue && authorizationHeaderValue.startsWith("Bearer")
				&& authorizationHeaderValue.length()>6) {
			String token = authorizationHeaderValue.substring(7, authorizationHeaderValue.length());
			OauthTokenDetailsEntity oAuthTokenDetailsEntity = userMasterService
					.getOauthTokenDetailsEntityByAccessToken(token, "N");
			if (null == oAuthTokenDetailsEntity) {
				response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
				response.setContentType(MediaType.APPLICATION_JSON_VALUE);
				response.getWriter().write("Access token is not valid");
				response.getWriter().flush();
				return false;
			}
		}else if(null != authorizationHeaderValue && !authorizationHeaderValue.startsWith("Bearer")
				&& authorizationHeaderValue.length()<6){
			response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
			response.setContentType(MediaType.APPLICATION_JSON_VALUE);
			response.getWriter().write("Access token is not valid");
			response.getWriter().flush();
			return false;
		}
		String dsmId = "";
		if (!StringUtils.isEmpty(request.getHeader("dsmId"))) {
			dsmId = (String) request.getHeader("dsmId");
		}
		String decryptedDsmId;
		decryptedDsmId = DESedeEncryption.decipher(DESedeEncryption.secretKey, dsmId);
		String[] strArray;
		try {
			strArray = decryptedDsmId.split("_");
			Long dataSourceMappingId = Long.parseLong(strArray[0]);
			Optional<DataSourceMappingEntity> dataSourceMappingEntityOptional = dbMappingService
					.findById(dataSourceMappingId);
			if (dataSourceMappingEntityOptional.isPresent()) {
				LOGGER.info("Set TenantContext: {}", dataSourceMappingEntityOptional.get().getTenantId());
				if (!TenantContext.getCurrentTenant()
						.equalsIgnoreCase(dataSourceMappingEntityOptional.get().getTenantId()))
					TenantContext.setCurrentTenant(dataSourceMappingEntityOptional.get().getTenantId());
				if (strArray.length > 1) {
					Long userId = Long.valueOf(strArray[1]);
					Optional<UserEntity> userEntityOptional = userRepository
							.findByUserIdAndIsDeletedAndConfirmationStatus(userId, Boolean.FALSE, Boolean.TRUE);
					if (userEntityOptional.isPresent()) {
						request.setAttribute("userEntity", userEntityOptional.get());
					}
				}
			}
		} catch (Exception e) {
			response.setStatus(HttpStatus.NOT_ACCEPTABLE.value());
			response.setContentType(MediaType.APPLICATION_JSON_VALUE);
			response.getWriter().write("{\"error\": \"please provide valid dsmId \"}");
			response.getWriter().flush();
		}
		return true;
	}

	@Override
	public void postHandle(HttpServletRequest request, HttpServletResponse response, Object handler,
			ModelAndView modelAndView) throws Exception {

		LOGGER.info("Clear TenantContext: {}", TenantContext.getCurrentTenant());
		TenantContext.clear();
	}

}
