package com.engage.zapier.controller;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.engage.zapier.entity.common.UserEntity;
import com.engage.zapier.request.WebhookRequest;
import com.engage.zapier.response.ServiceResponse;
import com.engage.zapier.service.ZapierService;

import io.swagger.annotations.ApiParam;

@RestController
@RequestMapping("/engage")
public class ZapierController {

	@Autowired
	private ZapierService zapierService;

	@GetMapping("/user/info")
	public <T> ServiceResponse<T> getUserInfo(HttpServletRequest request,
			@RequestHeader("dsmId") @ApiParam(required = true) String dsmId) {
		UserEntity userEntity = (UserEntity) request.getAttribute("userEntity");
		return zapierService.getUserInfo(userEntity);
	}

	@GetMapping("/lead/fields")
	public <T> ServiceResponse<T> getLeadFields(HttpServletRequest request,
			@RequestHeader("dsmId") @ApiParam(required = true) String dsmId) {
		UserEntity userEntity = (UserEntity) request.getAttribute("userEntity");
		return zapierService.getLeadFields(userEntity);
	}
	
	@GetMapping("/lead/list")
	public <T> ServiceResponse<T> getLeadList(HttpServletRequest request,
			@RequestHeader("dsmId") @ApiParam(required = true) String dsmId) {
		UserEntity userEntity = (UserEntity) request.getAttribute("userEntity");
		return zapierService.getLeadList(userEntity);
	}
	
	@PostMapping("/subscribe/webhook")
	public <T> ServiceResponse<T> subscriberWebHook(HttpServletRequest request,
			@RequestHeader("dsmId") @ApiParam(required = true) String dsmId,@RequestBody WebhookRequest webhookRequest) {
		UserEntity userEntity = (UserEntity) request.getAttribute("userEntity");
		return zapierService.subscribeWebHook(webhookRequest,userEntity,dsmId);
	}
	
	@DeleteMapping("/unsubscribe/webhook/{id}")
	public <T> ServiceResponse<T> unsubscribeWebHook(HttpServletRequest request,
			@RequestHeader("dsmId") @ApiParam(required = true) String dsmId,@PathVariable("id")Long id) {
		UserEntity userEntity = (UserEntity) request.getAttribute("userEntity");
		return zapierService.unsubscribeWebHook(id,userEntity,dsmId);
	}

}
