package com.engage.zapier.controller.advice;

import java.text.DateFormat;
import java.text.SimpleDateFormat;

import javax.servlet.http.HttpServletRequest;

import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.method.HandlerMethod;

import com.engage.zapier.exception.CustomErrorMessage;
import com.engage.zapier.exception.ResourceNotFoundException;
import com.engage.zapier.exception.ZapierServiceException;
import com.engage.zapier.response.ServiceResponse;



@org.springframework.web.bind.annotation.ControllerAdvice
@Order(Ordered.HIGHEST_PRECEDENCE)
public class ControllerAdvice {

  public static final DateFormat getDateTimeFormat() {
    return new SimpleDateFormat("yyyy-MMM-dd HH:mm:ss");
  }

  @ExceptionHandler(ZapierServiceException.class)
  public ServiceResponse<CustomErrorMessage> handleEmptyInputException(ZapierServiceException ex,
      HandlerMethod handlerMethod, HttpServletRequest req) {
    CustomErrorMessage error = new CustomErrorMessage();
    error.setStatusCode(ex.getStatusCode());
    error.setError(ex.getLocalizedMessage());
    error.setControllerName(String.valueOf(handlerMethod.getMethod().getDeclaringClass()));
    error.setMethodName(handlerMethod.getMethod().getName());
    error.setTimeStamp(getDateTimeFormat().format(System.currentTimeMillis()));
    error.setPath(req.getRequestURL().toString());
    return new ServiceResponse<>(error, HttpStatus.BAD_REQUEST);
  }

  @ExceptionHandler(NullPointerException.class)
  public ServiceResponse<CustomErrorMessage> handleNullPointerException(HttpServletRequest req,
      NullPointerException ex, HandlerMethod handlerMethod) {
    CustomErrorMessage error = new CustomErrorMessage();
    error.setStatusCode(HttpStatus.INTERNAL_SERVER_ERROR.value());
    error.setError(ex.getLocalizedMessage());
    error.setControllerName(String.valueOf(handlerMethod.getMethod().getDeclaringClass()));
    error.setMethodName(handlerMethod.getMethod().getName());
    error.setTimeStamp(getDateTimeFormat().format(System.currentTimeMillis()));
    error.setPath(req.getRequestURL().toString());

    return new ServiceResponse<>(error, HttpStatus.BAD_REQUEST);
  }

  @ExceptionHandler(ResourceNotFoundException.class)
  public ServiceResponse<CustomErrorMessage> resourceNotFoundException(ResourceNotFoundException ex,
      HttpServletRequest req, HandlerMethod handlerMethod) {
    CustomErrorMessage error = new CustomErrorMessage();
    error.setStatusCode(HttpStatus.NOT_FOUND.value());
    error.setError(ex.getLocalizedMessage());
    error.setControllerName(String.valueOf(handlerMethod.getMethod().getDeclaringClass()));
    error.setMethodName(handlerMethod.getMethod().getName());
    error.setTimeStamp(getDateTimeFormat().format(System.currentTimeMillis()));
    error.setPath(req.getRequestURL().toString());
    return new ServiceResponse<>(error, HttpStatus.NOT_FOUND);
  }

  @ExceptionHandler(IllegalArgumentException.class)
  protected ServiceResponse<CustomErrorMessage> handleConflict(IllegalArgumentException ex,
      HttpServletRequest req, HandlerMethod handlerMethod) {
    CustomErrorMessage error = new CustomErrorMessage();
    error.setStatusCode(HttpStatus.CONFLICT.value());
    error.setError(ex.getLocalizedMessage());
    error.setControllerName(String.valueOf(handlerMethod.getMethod().getDeclaringClass()));
    error.setMethodName(handlerMethod.getMethod().getName());
    error.setTimeStamp(getDateTimeFormat().format(System.currentTimeMillis()));
    error.setPath(req.getRequestURL().toString());
    return new ServiceResponse<>(error, HttpStatus.CONFLICT);
  }
}
