package com.engage.zapier.converter;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.util.function.BiFunction;
import java.util.function.Function;

public class DateTimeConverter {
  private DateTimeConverter() {}

  private static final DateTimeFormatter getDateTimeFormat() {
    return DateTimeFormatter.ofPattern("EE, MMM dd, yyyy | hh:mm:ss");
  }

  private static final DateTimeFormatter getStringToDateTimeFormat() {
    return DateTimeFormatter.ofPattern("dd/MM/yyyy");
  }

  private static final DateTimeFormatter getLocalTimeFormat() {
    return DateTimeFormatter.ofPattern("HH:mm");
  }

  private static final DateTimeFormatter getNewFormat() {
    return DateTimeFormatter.ofPattern("yyyy-MM-dd");
  }

  public static final BiFunction<LocalDateTime, String, String> convertDateTimeIntoStringByZone =
      (date, timezone) -> getDateTimeFormat()
          .format(date.atZone(ZoneId.systemDefault()).withZoneSameInstant(ZoneId.of(timezone)));

  public static final Function<String, LocalDateTime> convertStringLocalDateTime =
      stringDate -> LocalDate.parse(stringDate, getStringToDateTimeFormat()).atStartOfDay();

  public static final Function<LocalDateTime, String> convertDateTimeIntoString =
      date -> getDateTimeFormat().format(date);


  public static final Function<String, LocalTime> convertStringTimeToLocalTime =
      stringTime -> LocalTime.parse(stringTime);

  public static final Function<LocalTime, String> convertToLocalTimeToStringTime =
      localTime -> localTime.format(getLocalTimeFormat());

  public static final Function<String, LocalDateTime> convertDateToLocalDateTime =
      date -> LocalDateTime.of(LocalDate.parse(date, getNewFormat()),
          LocalDateTime.now().toLocalTime());



}
