package com.engage.zapier.entity.common;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Comparator;
import java.util.Set;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;

import com.engage.zapier.converter.BooleanConverter;
import com.engage.zapier.converter.LocalDateTimeConverter;

@Entity
@Table(name = "crm_fields")
public class CRMFieldEntity implements Serializable{

	/**
	 * 
	 */
	private static final long serialVersionUID = 8375289227042632558L;

	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	@Column(name = "field_id")
	private Long crmFieldId;

	@Column(name = "field_name")
	private String fieldName;

	@Column(name = "default_value")
	private String defaultValue;

	@Column(name = "field_length")
	private String fieldLength;

	@Column(name = "field_decimal_length")
	private String fieldDecimalLength;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "field_type_id", referencedColumnName = "master_data_id")
	private MasterDataEntity masterDataByFieldType;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "module_id", referencedColumnName = "module_id")
	private ModuleEntity moduleId;

	@OneToMany(mappedBy = "crmFieldEntityByPickListId", fetch = FetchType.LAZY)
	private Set<PicklistValuesEntity> pickListValueEntityByCrmFieldId;

	@Column(name = "is_Quick_Create")
	@Convert(converter = BooleanConverter.class)
	private Boolean isQuickCreateField;

	@Column(name = "is_mass_edit")
	@Convert(converter = BooleanConverter.class)
	private Boolean isMassEdit;	

	@Column(name = "is_search_filter")
	@Convert(converter = BooleanConverter.class)
	private Boolean isSearchFilter;

	@Column(name = "sort_order")
	private int sortOrder;

	@Column(name = "is_deleted")
	@Convert(converter = BooleanConverter.class)
	private Boolean isDeleted;

	@Column(name = "is_active")
	@Convert(converter = BooleanConverter.class)
	private Boolean isActive;	

	@Column(name = "is_mandatory")
	@Convert(converter = BooleanConverter.class)
	private Boolean isMandatory;

	@Column(name = "is_custom")
	private int isCustom;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "created_by", referencedColumnName = "user_id", nullable = false)
	private UserEntity createdBy;

	@Column(name = "created_date")
	@Convert(converter = LocalDateTimeConverter.class)
	private LocalDateTime createdDate;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "updated_by", referencedColumnName = "user_id", nullable = false)
	private UserEntity updatedBy;

	@Column(name = "updated_date")
	@Convert(converter = LocalDateTimeConverter.class)
	private LocalDateTime updatedDate;

	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "organisation_id", referencedColumnName = "organization_id")
	private SubscriberOrganizationEntity subscriberOrganizationByOrganizationId;

	@Column(name = "is_import")
	@Convert(converter = BooleanConverter.class)
	private Boolean isImport;

	@Column(name = "is_export")
	@Convert(converter = BooleanConverter.class)
	private Boolean isExport;

	@Column(name = "form_field_name")
	private String formFieldName;

	@Column(name = "field_key")
	private String fieldKey;

	@Column(name = "field_class_name")
	private String fieldClassName;

	@Column(name = "field_property_name")
	private String fieldPropertyName;

	
	public Long getCrmFieldId() {
		return crmFieldId;
	}

	public void setCrmFieldId(Long crmFieldId) {
		this.crmFieldId = crmFieldId;
	}

	public String getFieldName() {
		return fieldName;
	}

	public void setFieldName(String fieldName) {
		this.fieldName = fieldName;
	}

	public String getDefaultValue() {
		return defaultValue;
	}

	public void setDefaultValue(String defaultValue) {
		this.defaultValue = defaultValue;
	}

	public String getFieldLength() {
		return fieldLength;
	}

	public void setFieldLength(String fieldLength) {
		this.fieldLength = fieldLength;
	}

	public String getFieldDecimalLength() {
		return fieldDecimalLength;
	}

	public void setFieldDecimalLength(String fieldDecimalLength) {
		this.fieldDecimalLength = fieldDecimalLength;
	}

	public MasterDataEntity getMasterDataByFieldType() {
		return masterDataByFieldType;
	}

	public void setMasterDataByFieldType(MasterDataEntity masterDataByFieldType) {
		this.masterDataByFieldType = masterDataByFieldType;
	}

	public ModuleEntity getModuleId() {
		return moduleId;
	}

	public void setModuleId(ModuleEntity moduleId) {
		this.moduleId = moduleId;
	}

	public Set<PicklistValuesEntity> getPickListValueEntityByCrmFieldId() {
		return pickListValueEntityByCrmFieldId;
	}

	public void setPickListValueEntityByCrmFieldId(Set<PicklistValuesEntity> pickListValueEntityByCrmFieldId) {
		this.pickListValueEntityByCrmFieldId = pickListValueEntityByCrmFieldId;
	}

	public Boolean getIsQuickCreateField() {
		return isQuickCreateField;
	}

	public void setIsQuickCreateField(Boolean isQuickCreateField) {
		this.isQuickCreateField = isQuickCreateField;
	}

	public Boolean getIsMassEdit() {
		return isMassEdit;
	}

	public void setIsMassEdit(Boolean isMassEdit) {
		this.isMassEdit = isMassEdit;
	}

	public Boolean getIsSearchFilter() {
		return isSearchFilter;
	}

	public void setIsSearchFilter(Boolean isSearchFilter) {
		this.isSearchFilter = isSearchFilter;
	}

	public int getSortOrder() {
		return sortOrder;
	}

	public void setSortOrder(int sortOrder) {
		this.sortOrder = sortOrder;
	}

	public Boolean getIsMandatory() {
		return isMandatory;
	}

	public void setIsMandatory(Boolean isMandatory) {
		this.isMandatory = isMandatory;
	}

	public int getIsCustom() {
		return isCustom;
	}

	public void setIsCustom(int isCustom) {
		this.isCustom = isCustom;
	}

	public UserEntity getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(UserEntity createdBy) {
		this.createdBy = createdBy;
	}

	public LocalDateTime getCreatedDate() {
		return createdDate;
	}

	public void setCreatedDate(LocalDateTime createdDate) {
		this.createdDate = createdDate;
	}

	public UserEntity getUpdatedBy() {
		return updatedBy;
	}

	public void setUpdatedBy(UserEntity updatedBy) {
		this.updatedBy = updatedBy;
	}

	public LocalDateTime getUpdatedDate() {
		return updatedDate;
	}

	public void setUpdatedDate(LocalDateTime updatedDate) {
		this.updatedDate = updatedDate;
	}

	public SubscriberOrganizationEntity getSubscriberOrganizationByOrganizationId() {
		return subscriberOrganizationByOrganizationId;
	}

	public void setSubscriberOrganizationByOrganizationId(
			SubscriberOrganizationEntity subscriberOrganizationByOrganizationId) {
		this.subscriberOrganizationByOrganizationId = subscriberOrganizationByOrganizationId;
	}

	public Boolean getIsImport() {
		return isImport;
	}

	public void setIsImport(Boolean isImport) {
		this.isImport = isImport;
	}

	public Boolean getIsExport() {
		return isExport;
	}

	public void setIsExport(Boolean isExport) {
		this.isExport = isExport;
	}

	public String getFormFieldName() {
		return formFieldName;
	}

	public void setFormFieldName(String formFieldName) {
		this.formFieldName = formFieldName;
	}

	public String getFieldKey() {
		return fieldKey;
	}

	public void setFieldKey(String fieldKey) {
		this.fieldKey = fieldKey;
	}

	public String getFieldClassName() {
		return fieldClassName;
	}

	public void setFieldClassName(String fieldClassName) {
		this.fieldClassName = fieldClassName;
	}

	public String getFieldPropertyName() {
		return fieldPropertyName;
	}

	public void setFieldPropertyName(String fieldPropertyName) {
		this.fieldPropertyName = fieldPropertyName;
	}

	public Boolean getIsDeleted() {
		return isDeleted;
	}

	public void setIsDeleted(Boolean isDeleted) {
		this.isDeleted = isDeleted;
	}

	public Boolean getIsActive() {
		return isActive;
	}

	public void setIsActive(Boolean isActive) {
		this.isActive = isActive;
	}

	 /*Comparator for sorting the list by Sort order*/
    public static Comparator<CRMFieldEntity> sortByOrder = new Comparator<CRMFieldEntity>() {

		public int compare(CRMFieldEntity s1, CRMFieldEntity s2) {
		   int so1 = s1.getSortOrder();
		   int so2 = s2.getSortOrder();
		   /*ascending order*/
		   return Integer.valueOf(so1).compareTo(so2);
		   /*descending order*/
		   //return userName2.compareTo(userName1);
	    }

    };

}
