package com.engage.zapier.entity.common;

import java.time.LocalDateTime;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import com.engage.zapier.converter.BooleanConverter;
import com.engage.zapier.converter.LocalDateTimeConverter;

@Entity
@Table(name = "lead")
public class LeadEntity {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "lead_id")
    private Long leadId;

    @Column(name = "first_name")
    private String firstName;

    @Column(name = "last_name")
    private String lastName;

    @Column(name = "middle_name")
    private String middleName;

    @Column(name = "company")
    private String company;

    @Column(name = "role")
    private String role;

    @Column(name = "email")
    private String email;

    @Column(name = "phone")
    private String phone;

    @Column(name = "fax")
    private String fax;

    @Column(name = "mobile")
    private String mobile;

    @Column(name = "website")
    private String website;

    @Column(name = "no_of_employees")
    private Long noOfEmployees;

    @Column(name = "annual_revenue")
    private Double annualRevenue;

    @Column(name = "year_started")
    private String yearStarted;

    @Column(name = "secondary_email")
    private String secondaryEmail;

    @Column(name = "is_deleted")
    @Convert(converter = BooleanConverter.class)
    private Boolean isDeleted;
    
    /*@Column(name = "is_deleted")
	private String isDeleted;*/

    @Column(name = "updated_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime updatedDate;

    @Column(name = "created_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime createdDate;

    @Column(name = "skype_id")
    private String skypeId;

    @Column(name = "twitter_id")
    private String twitterId;

    @Column(name = "CREATED_FROM")
    private String createdFrom;

    @Column(name = "DEPARTMENT")
    private String department;

    @Column(name = "no_of_locations")
    private Long noOfLocations;

    @Column(name = "dob")
    private String dob;

    @Column(name = "marriage_anniversary")
    private String marriageAnniversary;

    @Column(name = "religion")
    private String religion;

    @Column(name = "nationality")
    private String nationality;

    @Column(name = "sic_Code")
    private String sicCode;

    @Column(name = "naics_Code")
    private String naicsCode;

    @Column(name = "description")
    private String description;

    @Column(name = "language")
    private String language;

    @Column(name = "facebook_url")
    private String facebookUrl;

    @Column(name = "linkedin_url")
    private String linkedinUrl;

    @Column(name = "reason_other")
    private String reasonOther;

    @Column(name = "linkedin_person_id")
    private String linkedinPersonId;

    @Column(name = "picture_url")
    private String pictureUrl;

    @Column(name = "linkedin_full_address")
    private String linkedinFullAddress;

    @Column(name = "skype_url")
    private String skypeUrl;

    @Column(name = "google_plus_url")
    private String googlePlusUrl;

    @Column(name = "image_file_key")
    private String imageFileKey;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "assign_to", referencedColumnName = "user_id")
    private UserEntity assignTo;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "lead_owner", referencedColumnName = "user_id", nullable = false)
    private UserEntity leadOwner;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "lead_created_by", referencedColumnName = "user_id", nullable = false)
    private UserEntity createdBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "lead_type", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByLeadType;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "title", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByTitle;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "lead_source", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByLeadSource;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "lead_status", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByLeadStatus;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "industry", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByIndustry;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "rating", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByRating;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "lead_address", referencedColumnName = "lead_address_id", nullable = false)
    private LeadAddressEntity leadAddressByLeadAddress;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "product_id", referencedColumnName = "product_id")
    private ProductEntity productNewByProductId;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "updated_by", referencedColumnName = "user_id")
    private UserEntity updatedBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "gender", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByGender;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "marital_status", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByMaritalStatus;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "reason", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByReason;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "campaign_id", referencedColumnName = "campaign_db_id")
    private SocialCampaignMasterEntity socialCampaignMasterByCampaignId;
    
	public Long getLeadId() {
		return leadId;
	}
	
	public void setLeadId(Long leadId) {
		this.leadId = leadId;
	}

	public String getFirstName() {
		return firstName;
	}

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getLastName() {
		return lastName;
	}

	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public String getMiddleName() {
		return middleName;
	}

	public void setMiddleName(String middleName) {
		this.middleName = middleName;
	}

	public String getCompany() {
		return company;
	}

	public void setCompany(String company) {
		this.company = company;
	}

	public String getRole() {
		return role;
	}

	public void setRole(String role) {
		this.role = role;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	public String getPhone() {
		return phone;
	}

	public void setPhone(String phone) {
		this.phone = phone;
	}

	public String getFax() {
		return fax;
	}

	public void setFax(String fax) {
		this.fax = fax;
	}

	public String getMobile() {
		return mobile;
	}

	public void setMobile(String mobile) {
		this.mobile = mobile;
	}

	public String getWebsite() {
		return website;
	}

	public void setWebsite(String website) {
		this.website = website;
	}

	public Long getNoOfEmployees() {
		return noOfEmployees;
	}

	public void setNoOfEmployees(Long noOfEmployees) {
		this.noOfEmployees = noOfEmployees;
	}

	public Double getAnnualRevenue() {
		return annualRevenue;
	}

	public void setAnnualRevenue(Double annualRevenue) {
		this.annualRevenue = annualRevenue;
	}

	public String getYearStarted() {
		return yearStarted;
	}

	public void setYearStarted(String yearStarted) {
		this.yearStarted = yearStarted;
	}

	public String getSecondaryEmail() {
		return secondaryEmail;
	}

	public void setSecondaryEmail(String secondaryEmail) {
		this.secondaryEmail = secondaryEmail;
	}

	public Boolean getIsDeleted() {
		return isDeleted;
	}

	public void setIsDeleted(Boolean isDeleted) {
		this.isDeleted = isDeleted;
	}
	
	/*public String getIsDeleted() {
		return isDeleted;
	}

	public void setIsDeleted(String isDeleted) {
		this.isDeleted = isDeleted;
	}*/

	public LocalDateTime getUpdatedDate() {
		return updatedDate;
	}

	public void setUpdatedDate(LocalDateTime updatedDate) {
		this.updatedDate = updatedDate;
	}

	public LocalDateTime getCreatedDate() {
		return createdDate;
	}

	public void setCreatedDate(LocalDateTime createdDate) {
		this.createdDate = createdDate;
	}

	public String getSkypeId() {
		return skypeId;
	}

	public void setSkypeId(String skypeId) {
		this.skypeId = skypeId;
	}

	public String getTwitterId() {
		return twitterId;
	}

	public void setTwitterId(String twitterId) {
		this.twitterId = twitterId;
	}

	public String getCreatedFrom() {
		return createdFrom;
	}

	public void setCreatedFrom(String createdFrom) {
		this.createdFrom = createdFrom;
	}

	public String getDepartment() {
		return department;
	}

	public void setDepartment(String department) {
		this.department = department;
	}

	public Long getNoOfLocations() {
		return noOfLocations;
	}

	public void setNoOfLocations(Long noOfLocations) {
		this.noOfLocations = noOfLocations;
	}

	public String getDob() {
		return dob;
	}

	public void setDob(String dob) {
		this.dob = dob;
	}

	public String getMarriageAnniversary() {
		return marriageAnniversary;
	}

	public void setMarriageAnniversary(String marriageAnniversary) {
		this.marriageAnniversary = marriageAnniversary;
	}

	public String getReligion() {
		return religion;
	}

	public void setReligion(String religion) {
		this.religion = religion;
	}

	public String getNationality() {
		return nationality;
	}

	public void setNationality(String nationality) {
		this.nationality = nationality;
	}

	public String getSicCode() {
		return sicCode;
	}

	public void setSicCode(String sicCode) {
		this.sicCode = sicCode;
	}



	public String getNaicsCode() {
		return naicsCode;
	}



	public void setNaicsCode(String naicsCode) {
		this.naicsCode = naicsCode;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public String getLanguage() {
		return language;
	}

	public void setLanguage(String language) {
		this.language = language;
	}

	public String getFacebookUrl() {
		return facebookUrl;
	}

	public void setFacebookUrl(String facebookUrl) {
		this.facebookUrl = facebookUrl;
	}

	public String getLinkedinUrl() {
		return linkedinUrl;
	}

	public void setLinkedinUrl(String linkedinUrl) {
		this.linkedinUrl = linkedinUrl;
	}

	public String getReasonOther() {
		return reasonOther;
	}

	public void setReasonOther(String reasonOther) {
		this.reasonOther = reasonOther;
	}

	public String getLinkedinPersonId() {
		return linkedinPersonId;
	}

	public void setLinkedinPersonId(String linkedinPersonId) {
		this.linkedinPersonId = linkedinPersonId;
	}

	public String getPictureUrl() {
		return pictureUrl;
	}

	public void setPictureUrl(String pictureUrl) {
		this.pictureUrl = pictureUrl;
	}

	public String getLinkedinFullAddress() {
		return linkedinFullAddress;
	}

	public void setLinkedinFullAddress(String linkedinFullAddress) {
		this.linkedinFullAddress = linkedinFullAddress;
	}

	public String getSkypeUrl() {
		return skypeUrl;
	}

	public void setSkypeUrl(String skypeUrl) {
		this.skypeUrl = skypeUrl;
	}

	public String getGooglePlusUrl() {
		return googlePlusUrl;
	}

	public void setGooglePlusUrl(String googlePlusUrl) {
		this.googlePlusUrl = googlePlusUrl;
	}

	public String getImageFileKey() {
		return imageFileKey;
	}

	public void setImageFileKey(String imageFileKey) {
		this.imageFileKey = imageFileKey;
	}

	public UserEntity getAssignTo() {
		return assignTo;
	}

	public void setAssignTo(UserEntity assignTo) {
		this.assignTo = assignTo;
	}

	public UserEntity getLeadOwner() {
		return leadOwner;
	}

	public void setLeadOwner(UserEntity leadOwner) {
		this.leadOwner = leadOwner;
	}

	public UserEntity getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(UserEntity createdBy) {
		this.createdBy = createdBy;
	}

	public MasterDataEntity getMasterDataByLeadType() {
		return masterDataByLeadType;
	}

	public void setMasterDataByLeadType(MasterDataEntity masterDataByLeadType) {
		this.masterDataByLeadType = masterDataByLeadType;
	}

	public MasterDataEntity getMasterDataByTitle() {
		return masterDataByTitle;
	}

	public void setMasterDataByTitle(MasterDataEntity masterDataByTitle) {
		this.masterDataByTitle = masterDataByTitle;
	}

	public MasterDataEntity getMasterDataByLeadSource() {
		return masterDataByLeadSource;
	}

	public void setMasterDataByLeadSource(MasterDataEntity masterDataByLeadSource) {
		this.masterDataByLeadSource = masterDataByLeadSource;
	}

	public MasterDataEntity getMasterDataByLeadStatus() {
		return masterDataByLeadStatus;
	}

	public void setMasterDataByLeadStatus(MasterDataEntity masterDataByLeadStatus) {
		this.masterDataByLeadStatus = masterDataByLeadStatus;
	}

	public MasterDataEntity getMasterDataByIndustry() {
		return masterDataByIndustry;
	}

	public void setMasterDataByIndustry(MasterDataEntity masterDataByIndustry) {
		this.masterDataByIndustry = masterDataByIndustry;
	}

	public MasterDataEntity getMasterDataByRating() {
		return masterDataByRating;
	}

	public void setMasterDataByRating(MasterDataEntity masterDataByRating) {
		this.masterDataByRating = masterDataByRating;
	}

	public LeadAddressEntity getLeadAddressByLeadAddress() {
		return leadAddressByLeadAddress;
	}

	public void setLeadAddressByLeadAddress(LeadAddressEntity leadAddressByLeadAddress) {
		this.leadAddressByLeadAddress = leadAddressByLeadAddress;
	}

	public ProductEntity getProductNewByProductId() {
		return productNewByProductId;
	}

	public void setProductNewByProductId(ProductEntity productNewByProductId) {
		this.productNewByProductId = productNewByProductId;
	}

	public UserEntity getUpdatedBy() {
		return updatedBy;
	}

	public void setUpdatedBy(UserEntity updatedBy) {
		this.updatedBy = updatedBy;
	}

	public MasterDataEntity getMasterDataByGender() {
		return masterDataByGender;
	}

	public void setMasterDataByGender(MasterDataEntity masterDataByGender) {
		this.masterDataByGender = masterDataByGender;
	}

	public MasterDataEntity getMasterDataByMaritalStatus() {
		return masterDataByMaritalStatus;
	}

	public void setMasterDataByMaritalStatus(MasterDataEntity masterDataByMaritalStatus) {
		this.masterDataByMaritalStatus = masterDataByMaritalStatus;
	}

	public MasterDataEntity getMasterDataByReason() {
		return masterDataByReason;
	}

	public void setMasterDataByReason(MasterDataEntity masterDataByReason) {
		this.masterDataByReason = masterDataByReason;
	}

	public SocialCampaignMasterEntity getSocialCampaignMasterByCampaignId() {
		return socialCampaignMasterByCampaignId;
	}

	public void setSocialCampaignMasterByCampaignId(SocialCampaignMasterEntity socialCampaignMasterByCampaignId) {
		this.socialCampaignMasterByCampaignId = socialCampaignMasterByCampaignId;
	}

	public String getLeadFullName() {
		String name = "" ;
		if(this.firstName != null){
			name = name + this.firstName;
		}
		if(this.firstName != null && this.lastName != null){
			name = name + " ";
		}
		if(this.lastName != null){
			name = name + this.lastName;
		}
		return name;
	}
}