package com.engage.zapier.entity.common;

import java.time.LocalDateTime;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import com.engage.zapier.converter.BooleanConverter;
import com.engage.zapier.converter.LocalDateTimeConverter;

@Entity
@Table(name = "product_new")

public class ProductEntity {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "product_id")
    private Long productId;

    @Column(name = "product_name")
    private String productName;

    @Column(name = "product_code")
    private String productCode;

    @Column(name = "active")
    private String active;

    @Column(name = "created_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime createdDate;

    @Column(name = "updated_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime updatedDate;

    @Column(name = "description")
    private String description;

    @Column(name = "price")
    private Long price;

    @Column(name = "is_deleted")
    @Convert(converter = BooleanConverter.class)
    private Boolean isDeleted;

    @Column(name = "product_sku_num")
    private String productSkuNum;

    @Column(name = "manufacturer")
    private String manufacturer;

    @Column(name = "vendor")
    private String vendor;

    @Column(name = "qty_in_stock")
    private Integer qtyInStock;

    @Column(name = "total_order")
    private Integer totalOrder;

    @Column(name = "reamining_qty")
    private Integer reaminingQty;

    @Column(name = "low_qty_alert")
    private Integer lowQtyAlert;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "product_price_id", referencedColumnName = "product_price_id")
    private ProductPriceEntity productPriceByProductPriceId;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "created_by", referencedColumnName = "user_id", nullable = false)
    private UserEntity createdBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "updated_by", referencedColumnName = "user_id")
    private UserEntity updatedBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "product_owner", referencedColumnName = "user_id", nullable = false)
    private UserEntity productOwner;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "product_category", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByProductCategory;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "usage_unit", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByUsageUnit;

	public Long getProductId() {
		return productId;
	}

	public void setProductId(Long productId) {
		this.productId = productId;
	}

	public String getProductName() {
		return productName;
	}

	public void setProductName(String productName) {
		this.productName = productName;
	}

	public String getProductCode() {
		return productCode;
	}

	public void setProductCode(String productCode) {
		this.productCode = productCode;
	}

	public String getActive() {
		return active;
	}

	public void setActive(String active) {
		this.active = active;
	}

	public LocalDateTime getCreatedDate() {
		return createdDate;
	}

	public void setCreatedDate(LocalDateTime createdDate) {
		this.createdDate = createdDate;
	}

	public LocalDateTime getUpdatedDate() {
		return updatedDate;
	}

	public void setUpdatedDate(LocalDateTime updatedDate) {
		this.updatedDate = updatedDate;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Long getPrice() {
		return price;
	}

	public void setPrice(Long price) {
		this.price = price;
	}

	public Boolean getIsDeleted() {
		return isDeleted;
	}

	public void setIsDeleted(Boolean isDeleted) {
		this.isDeleted = isDeleted;
	}

	public String getProductSkuNum() {
		return productSkuNum;
	}

	public void setProductSkuNum(String productSkuNum) {
		this.productSkuNum = productSkuNum;
	}

	public String getManufacturer() {
		return manufacturer;
	}

	public void setManufacturer(String manufacturer) {
		this.manufacturer = manufacturer;
	}

	public String getVendor() {
		return vendor;
	}

	public void setVendor(String vendor) {
		this.vendor = vendor;
	}

	public Integer getQtyInStock() {
		return qtyInStock;
	}

	public void setQtyInStock(Integer qtyInStock) {
		this.qtyInStock = qtyInStock;
	}

	public Integer getTotalOrder() {
		return totalOrder;
	}

	public void setTotalOrder(Integer totalOrder) {
		this.totalOrder = totalOrder;
	}

	public Integer getReaminingQty() {
		return reaminingQty;
	}

	public void setReaminingQty(Integer reaminingQty) {
		this.reaminingQty = reaminingQty;
	}

	public Integer getLowQtyAlert() {
		return lowQtyAlert;
	}

	public void setLowQtyAlert(Integer lowQtyAlert) {
		this.lowQtyAlert = lowQtyAlert;
	}

	public ProductPriceEntity getProductPriceByProductPriceId() {
		return productPriceByProductPriceId;
	}

	public void setProductPriceByProductPriceId(ProductPriceEntity productPriceByProductPriceId) {
		this.productPriceByProductPriceId = productPriceByProductPriceId;
	}

	public UserEntity getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(UserEntity createdBy) {
		this.createdBy = createdBy;
	}

	public UserEntity getUpdatedBy() {
		return updatedBy;
	}

	public void setUpdatedBy(UserEntity updatedBy) {
		this.updatedBy = updatedBy;
	}

	public UserEntity getProductOwner() {
		return productOwner;
	}

	public void setProductOwner(UserEntity productOwner) {
		this.productOwner = productOwner;
	}

	public MasterDataEntity getMasterDataByProductCategory() {
		return masterDataByProductCategory;
	}

	public void setMasterDataByProductCategory(MasterDataEntity masterDataByProductCategory) {
		this.masterDataByProductCategory = masterDataByProductCategory;
	}

	public MasterDataEntity getMasterDataByUsageUnit() {
		return masterDataByUsageUnit;
	}

	public void setMasterDataByUsageUnit(MasterDataEntity masterDataByUsageUnit) {
		this.masterDataByUsageUnit = masterDataByUsageUnit;
	}



}
