package com.engage.zapier.entity.common;

import java.time.LocalDateTime;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import com.engage.zapier.converter.BooleanConverter;
import com.engage.zapier.converter.LocalDateTimeConverter;

@Entity
@Table(name = "role_new")
public class RoleEntity {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "role_id")
    private Long roleId;

    @Column(name = "role_name")
    private String roleName;

    @Column(name = "role_description")
    private String roleDescription;

    @Column(name = "created_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime createdDate;

    @Column(name = "updated_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime updatedDate;

    @Column(name = "is_deleted")
    @Convert(converter = BooleanConverter.class)
    private Boolean isDeleted;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "report_to", referencedColumnName = "role_id")
    private RoleEntity reportTo;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "created_By", referencedColumnName = "user_id", nullable = false)
    private UserEntity createdBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "updated_by", referencedColumnName = "user_id")
    private UserEntity updatedBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "organisation_id", referencedColumnName = "organization_id", nullable = false)
    private SubscriberOrganizationEntity subscriberOrganizationByOrganisationId;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "currency_Id", referencedColumnName = "master_data_id", nullable = false)
    private MasterDataEntity masterDataByCurrencyId;

	public Long getRoleId() {
		return roleId;
	}

	public void setRoleId(Long roleId) {
		this.roleId = roleId;
	}

	public String getRoleName() {
		return roleName;
	}

	public void setRoleName(String roleName) {
		this.roleName = roleName;
	}

	public String getRoleDescription() {
		return roleDescription;
	}

	public void setRoleDescription(String roleDescription) {
		this.roleDescription = roleDescription;
	}

	public LocalDateTime getCreatedDate() {
		return createdDate;
	}

	public void setCreatedDate(LocalDateTime createdDate) {
		this.createdDate = createdDate;
	}

	public LocalDateTime getUpdatedDate() {
		return updatedDate;
	}

	public void setUpdatedDate(LocalDateTime updatedDate) {
		this.updatedDate = updatedDate;
	}

	public Boolean getIsDeleted() {
		return isDeleted;
	}

	public void setIsDeleted(Boolean isDeleted) {
		this.isDeleted = isDeleted;
	}

	public RoleEntity getReportTo() {
		return reportTo;
	}

	public void setReportTo(RoleEntity reportTo) {
		this.reportTo = reportTo;
	}

	public UserEntity getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(UserEntity createdBy) {
		this.createdBy = createdBy;
	}

	public UserEntity getUpdatedBy() {
		return updatedBy;
	}

	public void setUpdatedBy(UserEntity updatedBy) {
		this.updatedBy = updatedBy;
	}

	public SubscriberOrganizationEntity getSubscriberOrganizationByOrganisationId() {
		return subscriberOrganizationByOrganisationId;
	}

	public void setSubscriberOrganizationByOrganisationId(
			SubscriberOrganizationEntity subscriberOrganizationByOrganisationId) {
		this.subscriberOrganizationByOrganisationId = subscriberOrganizationByOrganisationId;
	}

	public MasterDataEntity getMasterDataByCurrencyId() {
		return masterDataByCurrencyId;
	}

	public void setMasterDataByCurrencyId(MasterDataEntity masterDataByCurrencyId) {
		this.masterDataByCurrencyId = masterDataByCurrencyId;
	}
}