package com.engage.zapier.entity.common;

import java.time.LocalDateTime;

import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import com.engage.zapier.converter.BooleanConverter;
import com.engage.zapier.converter.LocalDateTimeConverter;


@Entity
@Table(name = "social_campaign_master")
public class SocialCampaignMasterEntity {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "campaign_db_id")
    private Long campaignDbId;

    @Column(name = "campaign_id")
    private String campaignId;

    @Column(name = "campaign_title")
    private String campaignTitle;

    @Column(name = "campaign_description")
    private String campaignDescription;

    @Column(name = "created_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime createdDate;

    @Column(name = "updated_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime updatedDate;

    @Column(name = "is_deleted")
    @Convert(converter = BooleanConverter.class)
    private Boolean isDeleted;

    @Column(name = "campaign_start_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime campaignStartDate;

    @Column(name = "campaign_end_date")
    private String campaignEndDate;

    @Column(name = "expected_revenue")
    private Long expectedRevenue;

    @Column(name = "budgeted_cost")
    private Long budgetedCost;

    @Column(name = "actual_cost")
    private Long actualCost;

    @Column(name = "mail_campaign_title")
    private String mailCampaignTitle;

    @Column(name = "mail_campaign_id")
    private String mailCampaignId;

    @Column(name = "domain_name")
    private String domainName;

    @Column(name = "thirdparty_api")
    private String thirdpartyApi;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "campaign_owner", referencedColumnName = "user_id", nullable = false)
    private UserEntity campaignOwner;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "created_by", referencedColumnName = "user_id", nullable = false)
    private UserEntity createdBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "updated_by", referencedColumnName = "user_id")
    private UserEntity updatedBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "campaign_type", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByCampaignType;

	public Long getCampaignDbId() {
		return campaignDbId;
	}

	public void setCampaignDbId(Long campaignDbId) {
		this.campaignDbId = campaignDbId;
	}

	public String getCampaignId() {
		return campaignId;
	}

	public void setCampaignId(String campaignId) {
		this.campaignId = campaignId;
	}

	public String getCampaignTitle() {
		return campaignTitle;
	}

	public void setCampaignTitle(String campaignTitle) {
		this.campaignTitle = campaignTitle;
	}

	public String getCampaignDescription() {
		return campaignDescription;
	}

	public void setCampaignDescription(String campaignDescription) {
		this.campaignDescription = campaignDescription;
	}

	public LocalDateTime getCreatedDate() {
		return createdDate;
	}

	public void setCreatedDate(LocalDateTime createdDate) {
		this.createdDate = createdDate;
	}

	public LocalDateTime getUpdatedDate() {
		return updatedDate;
	}

	public void setUpdatedDate(LocalDateTime updatedDate) {
		this.updatedDate = updatedDate;
	}

	public Boolean getIsDeleted() {
		return isDeleted;
	}

	public void setIsDeleted(Boolean isDeleted) {
		this.isDeleted = isDeleted;
	}

	public LocalDateTime getCampaignStartDate() {
		return campaignStartDate;
	}

	public void setCampaignStartDate(LocalDateTime campaignStartDate) {
		this.campaignStartDate = campaignStartDate;
	}

	public String getCampaignEndDate() {
		return campaignEndDate;
	}

	public void setCampaignEndDate(String campaignEndDate) {
		this.campaignEndDate = campaignEndDate;
	}

	public Long getExpectedRevenue() {
		return expectedRevenue;
	}

	public void setExpectedRevenue(Long expectedRevenue) {
		this.expectedRevenue = expectedRevenue;
	}

	public Long getBudgetedCost() {
		return budgetedCost;
	}

	public void setBudgetedCost(Long budgetedCost) {
		this.budgetedCost = budgetedCost;
	}

	public Long getActualCost() {
		return actualCost;
	}

	public void setActualCost(Long actualCost) {
		this.actualCost = actualCost;
	}

	public String getMailCampaignTitle() {
		return mailCampaignTitle;
	}

	public void setMailCampaignTitle(String mailCampaignTitle) {
		this.mailCampaignTitle = mailCampaignTitle;
	}

	public String getMailCampaignId() {
		return mailCampaignId;
	}

	public void setMailCampaignId(String mailCampaignId) {
		this.mailCampaignId = mailCampaignId;
	}

	public String getDomainName() {
		return domainName;
	}

	public void setDomainName(String domainName) {
		this.domainName = domainName;
	}

	public String getThirdpartyApi() {
		return thirdpartyApi;
	}

	public void setThirdpartyApi(String thirdpartyApi) {
		this.thirdpartyApi = thirdpartyApi;
	}

	public UserEntity getCampaignOwner() {
		return campaignOwner;
	}

	public void setCampaignOwner(UserEntity campaignOwner) {
		this.campaignOwner = campaignOwner;
	}

	public UserEntity getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(UserEntity createdBy) {
		this.createdBy = createdBy;
	}

	public UserEntity getUpdatedBy() {
		return updatedBy;
	}

	public void setUpdatedBy(UserEntity updatedBy) {
		this.updatedBy = updatedBy;
	}

	public MasterDataEntity getMasterDataByCampaignType() {
		return masterDataByCampaignType;
	}

	public void setMasterDataByCampaignType(MasterDataEntity masterDataByCampaignType) {
		this.masterDataByCampaignType = masterDataByCampaignType;
	}
}