package com.engage.zapier.entity.common;

import java.sql.Date;
import java.time.LocalDateTime;
import java.util.Comparator;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

import com.engage.zapier.converter.BooleanConverterForChar;
import com.engage.zapier.converter.LocalDateTimeConverter;

@Entity
@Table(name = "user_new")
public class UserEntity {

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "user_id" ,columnDefinition="VARCHAR")
    private Long userId;

    @Column(name = "first_name")
    private String firstName;

    @Column(name = "last_name")
    private String lastName;

    @Column(name = "mobile")
    private String mobile;

    @Column(name = "phone_number")
    private String phoneNumber;

    @Column(name = "dob")
    private Date dob;

    @Column(name = "fax")
    private String fax;

    @Column(name = "created_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime createdDate;

    @Column(name = "updated_date")
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime updatedDate;

    @Column(name = "is_deleted")
    @Convert(converter = BooleanConverterForChar.class)
    private Boolean isDeleted;

    @Column(name = "confirmation_status")
    @Convert(converter = BooleanConverterForChar.class)
    private Boolean confirmationStatus;

    @Column(name = "nlevel_access")
    @Convert(converter = BooleanConverterForChar.class)
    private Boolean nlevelAccess;

    @Column(name = "subscriber_id")
    private Long subscriberId;

    @Column(name = "picture_url")
    private String pictureUrl;

    @Column(name = "permanent_deleted")
    @Convert(converter = BooleanConverterForChar.class)
    private Boolean permanentDeleted;


    @Column(name = "agent_ext")
    private Integer agentExt;
    
    @Column(name = "agent_user")
    private String agentUser;
    
    @Column(name = "agent_pass")
    private String agentPass;
    
    @Column(name = "phone_user")
    private String phoneUser;
    
    @Column(name = "phone_pass")
    private String phonePass;
 
    @Column(name = "image_file_key")
    private String imageKey;
       
    
    
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "created_by", referencedColumnName = "user_id")
    private UserEntity createdBy;

    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "updated_by", referencedColumnName = "user_id")
    private UserEntity updatedBy;

    @ManyToOne(fetch = FetchType.EAGER)
    @JoinColumn(name = "report_to", referencedColumnName = "user_id")
    private UserEntity reportTo;

    @ManyToOne(fetch = FetchType.EAGER, cascade = CascadeType.ALL)
    @JoinColumn(name = "user_mapping_id", referencedColumnName = "user_mapping_id")
    private UserMappingsEntity userMappingsByUserMappingId;
    
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "title", referencedColumnName = "master_data_id")
    private MasterDataEntity masterDataByTitle;
    
	public Long getUserId() {
		return userId;
	}

	public void setUserId(Long userId) {
		this.userId = userId;
	}

	public String getFirstName() {
		return firstName;
	}

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getLastName() {
		return lastName;
	}

	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public String getMobile() {
		return mobile;
	}

	public void setMobile(String mobile) {
		this.mobile = mobile;
	}

	public String getPhoneNumber() {
		return phoneNumber;
	}

	public void setPhoneNumber(String phoneNumber) {
		this.phoneNumber = phoneNumber;
	}

	public Date getDob() {
		return dob;
	}

	public void setDob(Date dob) {
		this.dob = dob;
	}

	public String getFax() {
		return fax;
	}

	public void setFax(String fax) {
		this.fax = fax;
	}

	public LocalDateTime getCreatedDate() {
		return createdDate;
	}

	public void setCreatedDate(LocalDateTime createdDate) {
		this.createdDate = createdDate;
	}

	public LocalDateTime getUpdatedDate() {
		return updatedDate;
	}

	public void setUpdatedDate(LocalDateTime updatedDate) {
		this.updatedDate = updatedDate;
	}

	public Boolean getIsDeleted() {
		return isDeleted;
	}

	public void setIsDeleted(Boolean isDeleted) {
		this.isDeleted = isDeleted;
	}

	public Boolean getConfirmationStatus() {
		return confirmationStatus;
	}

	public void setConfirmationStatus(Boolean confirmationStatus) {
		this.confirmationStatus = confirmationStatus;
	}

	public Boolean getNlevelAccess() {
		return nlevelAccess;
	}

	public void setNlevelAccess(Boolean nlevelAccess) {
		this.nlevelAccess = nlevelAccess;
	}

	public Long getSubscriberId() {
		return subscriberId;
	}

	public void setSubscriberId(Long subscriberId) {
		this.subscriberId = subscriberId;
	}

	public String getPictureUrl() {
		return pictureUrl;
	}

	public void setPictureUrl(String pictureUrl) {
		this.pictureUrl = pictureUrl;
	}

	public Boolean getPermanentDeleted() {
		return permanentDeleted;
	}

	public void setPermanentDeleted(Boolean permanentDeleted) {
		this.permanentDeleted = permanentDeleted;
	}

	public Integer getAgentExt() {
		return agentExt;
	}

	public void setAgentExt(Integer agentExt) {
		this.agentExt = agentExt;
	}

	public String getAgentUser() {
		return agentUser;
	}

	public void setAgentUser(String agentUser) {
		this.agentUser = agentUser;
	}

	public String getAgentPass() {
		return agentPass;
	}

	public void setAgentPass(String agentPass) {
		this.agentPass = agentPass;
	}

	public String getPhoneUser() {
		return phoneUser;
	}

	public void setPhoneUser(String phoneUser) {
		this.phoneUser = phoneUser;
	}

	public String getPhonePass() {
		return phonePass;
	}

	public void setPhonePass(String phonePass) {
		this.phonePass = phonePass;
	}

	public String getImageKey() {
		return imageKey;
	}

	public void setImageKey(String imageKey) {
		this.imageKey = imageKey;
	}

	public UserEntity getCreatedBy() {
		return createdBy;
	}

	public void setCreatedBy(UserEntity createdBy) {
		this.createdBy = createdBy;
	}

	public UserEntity getUpdatedBy() {
		return updatedBy;
	}

	public void setUpdatedBy(UserEntity updatedBy) {
		this.updatedBy = updatedBy;
	}

	public UserEntity getReportTo() {
		return reportTo;
	}

	public void setReportTo(UserEntity reportTo) {
		this.reportTo = reportTo;
	}

	public UserMappingsEntity getUserMappingsByUserMappingId() {
		return userMappingsByUserMappingId;
	}

	public void setUserMappingsByUserMappingId(UserMappingsEntity userMappingsByUserMappingId) {
		this.userMappingsByUserMappingId = userMappingsByUserMappingId;
	}

	public MasterDataEntity getMasterDataByTitle() {
		return masterDataByTitle;
	}

	public void setMasterDataByTitle(MasterDataEntity masterDataByTitle) {
		this.masterDataByTitle = masterDataByTitle;
	}

	public String getUserFullName() {
		String name = "" ;
		if(this.firstName != null){
			name = name + this.firstName;
		}
		if(this.firstName != null && this.lastName != null){
			name = name + " ";
		}
		if(this.lastName != null){
			name = name + this.lastName;
		}
		return name;
	}
	
   public static Comparator<UserEntity> UserNameComparator = new Comparator<UserEntity>() {
		public int compare(UserEntity s1, UserEntity s2) {
		   Long userId1 = s1.getUserId();
		   Long userId2 = s2.getUserId();
		   return userId1.compareTo(userId2);
	    }
    };
}