package com.engage.zapier.repository.common;

import java.util.List;
import java.util.Optional;
import java.util.Set;

import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.CrudRepository;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import com.engage.zapier.entity.common.UserEntity;

@Repository
public interface UserRepository extends CrudRepository<UserEntity, Long> {
	
	Optional<UserEntity> findByUserIdAndIsDeletedAndConfirmationStatus(Long userId,Boolean isDeleted,Boolean confirmationStatus);
	
	@Query(value = "select user.userId from UserEntity user where user.reportTo.userId in (:userId) and user.isDeleted=:isDeleted and user.confirmationStatus=:confirmationStatus")
	Set<Long> getSubOrdinateList (@Param("userId") Set<Long> userIdSet,@Param("isDeleted") Boolean isDeleted,@Param("confirmationStatus")Boolean confirmationStatus);
	
	@Query(value ="select user.userId from UserEntity user,UserMappingsEntity userMapping where user.userMappingsByUserMappingId.userMappingId=userMapping.userMappingId and user.isDeleted=:isDel and user.confirmationStatus=:conf and user.permanentDeleted=:pDel  and userMapping.subscriberOrganizationByOrganizationId.organizationId=:OrgID")
	List<Long> getActiveUsersIDsOfOrganization(@Param("OrgID")Long organizationId,@Param("isDel") Boolean isDeleted,@Param("conf") Boolean confirmStatus,@Param("pDel") Boolean permanentDeleted);
	
	@Query(value ="select user.userId from UserEntity user where user.userMappingsByUserMappingId.subscriberOrganizationByOrganizationId.organizationId=:organizationId and user.userMappingsByUserMappingId.roleNewByRoleId.roleId in(:roleId) and user.isDeleted=:isDel and user.confirmationStatus=:conf and user.permanentDeleted=:pDel order by user.userMappingsByUserMappingId.roleNewByRoleId.roleId asc")
	Set<Long> getUsersIDListOfOrganizationByRoles(@Param("organizationId")Long organizationId,@Param("roleId")List<Long> roleIdSet,@Param("isDel") Boolean isDeleted,@Param("conf") Boolean confirmationStatus,@Param("pDel") Boolean permanentDeleted);
	
	@Query(value = "select user from UserEntity user where user.reportTo in (:userEntity) and user.isDeleted=:isDeleted and user.confirmationStatus=:confirmationStatus")
	Set<UserEntity> getNLevelSubordinateBeanForUserId (@Param("userEntity") Set<UserEntity> userEntity,@Param("isDeleted") Boolean isDeleted,@Param("confirmationStatus")Boolean confirmationStatus);
	
	@Query(value ="select user from UserEntity user where user.userMappingsByUserMappingId.subscriberOrganizationByOrganizationId.organizationId=:organizationId and user.userMappingsByUserMappingId.roleNewByRoleId.roleId in(:roleId) and user.isDeleted=:isDel and user.confirmationStatus=:conf and user.permanentDeleted=:pDel order by user.userMappingsByUserMappingId.roleNewByRoleId.roleId asc")
	List<UserEntity> getUsersListOfOrganizationByRoles(@Param("organizationId")Long organizationId,@Param("roleId")List<Long> roleIdSet,@Param("isDel") Boolean isDeleted,@Param("conf") Boolean confirmationStatus,@Param("pDel") Boolean permanentDeleted);
	
	@Query(value ="select user from UserEntity user,UserMappingsEntity userMapping where user.userMappingsByUserMappingId.userMappingId=userMapping.userMappingId and user.isDeleted=:isDel and user.confirmationStatus=:conf and user.permanentDeleted=:pDel  and userMapping.subscriberOrganizationByOrganizationId.organizationId=:OrgID")
	List<UserEntity> getActiveUsersEntityOfOrganization(@Param("OrgID")Long organizationId,@Param("isDel") Boolean isDeleted,@Param("conf") Boolean confirmStatus,@Param("pDel") Boolean permanentDeleted);
	
	@Query(value ="select user from UserEntity user,UserMappingsEntity userMapping where user.userMappingsByUserMappingId.teamByTeamId.teamId =:teamId and user.isDeleted=:isDel and user.confirmationStatus=:conf and user.permanentDeleted=:pDel")
	Set<UserEntity> getActiveUsersByTeamId(@Param("teamId")Long teamId,@Param("isDel") Boolean isDeleted,@Param("conf") Boolean confirmStatus,@Param("pDel") Boolean permanentDeleted);
	
	Set<UserEntity> findByUserIdInAndIsDeletedAndConfirmationStatus(Set<Long> userIdSet,Boolean isDeleted,Boolean confirmationStatus);
	
	
	@Query(value = "select user from UserEntity user where user.userId =:userId and user.isDeleted=:isDeleted and user.confirmationStatus=:confirmationStatus")
	UserEntity getUserById (@Param("userId") Long userId,@Param("isDeleted") Boolean isDeleted,@Param("confirmationStatus")Boolean confirmationStatus);
	
	@Query(value = "select user from UserEntity user where lower(concat(user.firstName,' ',user.lastName)) like :query and user.isDeleted=:isDeleted and user.confirmationStatus=:confirmationStatus")
	List<UserEntity> getUserByName (@Param("query") String userName,@Param("isDeleted") Boolean isDeleted,@Param("confirmationStatus")Boolean confirmationStatus);
	
	UserEntity findByUserId(Long userId);
}

