package com.engage.zapier.response;

import java.io.Serializable;

import com.engage.zapier.converter.DateTimeConverter;
import com.engage.zapier.entity.common.LeadEntity;
import com.fasterxml.jackson.annotation.JsonInclude;

/**
 * 
 * @author sajidshaikh
 *
 */

@JsonInclude(JsonInclude.Include.NON_EMPTY)
public class LeadResponse implements Serializable{
	

	/**
	 * 
	 */
	private static final long serialVersionUID = 5291665940388223806L;
	private Long leadId;
	private String email;
	private String phone;
	private String mobile;
	private String company;
	private String website;
	private String status;
	private String owner;
	private String createdOn;
	private String createdBy;
	private String updatedOn;
	private String updatedBy;
	
	public LeadResponse() {}
	
	/**
	 * This constructor is used to convert leadEntity object to leadResponse object
	 * @param leadEntity
	 * @return response object
	 */
	public LeadResponse(LeadEntity leadEntity) {
		this.leadId=leadEntity.getLeadId();
		this.email=leadEntity.getEmail() != null?leadEntity.getEmail():"";
		this.phone=leadEntity.getPhone() != null?leadEntity.getPhone():"";
		this.mobile=leadEntity.getMobile() != null?leadEntity.getMobile():"";
		this.company=leadEntity.getCompany() != null?leadEntity.getCompany():"";
		this.website=leadEntity.getWebsite() != null?leadEntity.getWebsite():"";
		this.status=leadEntity.getMasterDataByLeadStatus() != null?leadEntity.getMasterDataByLeadStatus().getDataValue():"";
		this.owner=leadEntity.getLeadOwner() != null?leadEntity.getLeadOwner().getUserFullName():"";
		this.createdBy=leadEntity.getCreatedBy() != null?leadEntity.getCreatedBy().getUserFullName():"";
		this.createdOn=leadEntity.getCreatedDate() != null?DateTimeConverter.convertDateTimeIntoString.apply(leadEntity.getCreatedDate()):"";
		this.updatedOn=leadEntity.getUpdatedDate() != null?DateTimeConverter.convertDateTimeIntoString.apply(leadEntity.getUpdatedDate()):"";
		this.updatedBy=leadEntity.getUpdatedBy() != null?leadEntity.getUpdatedBy().getUserFullName():"";
	}
	
	/**
	 * @return the leadId
	 */
	public Long getLeadId() {
		return leadId;
	}
	/**
	 * @param leadId the leadId to set
	 */
	public void setLeadId(Long leadId) {
		this.leadId = leadId;
	}
	/**
	 * @return the email
	 */
	public String getEmail() {
		return email;
	}
	/**
	 * @param email the email to set
	 */
	public void setEmail(String email) {
		this.email = email;
	}
	/**
	 * @return the phone
	 */
	public String getPhone() {
		return phone;
	}
	/**
	 * @param phone the phone to set
	 */
	public void setPhone(String phone) {
		this.phone = phone;
	}
	/**
	 * @return the mobile
	 */
	public String getMobile() {
		return mobile;
	}
	/**
	 * @param mobile the mobile to set
	 */
	public void setMobile(String mobile) {
		this.mobile = mobile;
	}
	/**
	 * @return the company
	 */
	public String getCompany() {
		return company;
	}
	/**
	 * @param company the company to set
	 */
	public void setCompany(String company) {
		this.company = company;
	}
	/**
	 * @return the website
	 */
	public String getWebsite() {
		return website;
	}
	/**
	 * @param website the website to set
	 */
	public void setWebsite(String website) {
		this.website = website;
	}
	/**
	 * @return the status
	 */
	public String getStatus() {
		return status;
	}
	/**
	 * @param status the status to set
	 */
	public void setStatus(String status) {
		this.status = status;
	}
	/**
	 * @return the owner
	 */
	public String getOwner() {
		return owner;
	}
	/**
	 * @param owner the owner to set
	 */
	public void setOwner(String owner) {
		this.owner = owner;
	}
	/**
	 * @return the createdOn
	 */
	public String getCreatedOn() {
		return createdOn;
	}
	/**
	 * @param createdOn the createdOn to set
	 */
	public void setCreatedOn(String createdOn) {
		this.createdOn = createdOn;
	}
	/**
	 * @return the createdBy
	 */
	public String getCreatedBy() {
		return createdBy;
	}
	/**
	 * @param createdBy the createdBy to set
	 */
	public void setCreatedBy(String createdBy) {
		this.createdBy = createdBy;
	}
	/**
	 * @return the updatedOn
	 */
	public String getUpdatedOn() {
		return updatedOn;
	}
	/**
	 * @param updatedOn the updatedOn to set
	 */
	public void setUpdatedOn(String updatedOn) {
		this.updatedOn = updatedOn;
	}
	/**
	 * @return the updatedBy
	 */
	public String getUpdatedBy() {
		return updatedBy;
	}
	/**
	 * @param updatedBy the updatedBy to set
	 */
	public void setUpdatedBy(String updatedBy) {
		this.updatedBy = updatedBy;
	}
	@Override
	public String toString() {
		return "LeadResponse [leadId=" + leadId + ", email=" + email + ", phone=" + phone + ", mobile=" + mobile
				+ ", company=" + company + ", website=" + website + ", status=" + status + ", owner=" + owner
				+ ", createdOn=" + createdOn + ", createdBy=" + createdBy + ", updatedOn=" + updatedOn + ", updatedBy="
				+ updatedBy + "]";
	}
	
	
}
