package com.engage.zapier.utility;

import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

import org.springframework.beans.factory.config.ConfigurableBeanFactory;
import org.springframework.context.annotation.Scope;
import org.springframework.context.annotation.ScopedProxyMode;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Component;

import com.engage.zapier.entity.common.MasterDataEntity;
import com.engage.zapier.exception.ZapierServiceException;
import com.engage.zapier.response.PicklistResponse;

@Component
@Scope(value = ConfigurableBeanFactory.SCOPE_SINGLETON, proxyMode = ScopedProxyMode.TARGET_CLASS)
public class MasterDataForStandardFields {

	private Map<String, List<MasterDataEntity>> masterDataFieldValueMap;
	private Map<Long, MasterDataEntity> masterDataMap;
	
	
	

	/**
	 * @return the masterDataFieldValueMap
	 */
	public Map<String, List<MasterDataEntity>> getMasterDataFieldValueMap() {
		return masterDataFieldValueMap;
	}

	/**
	 * @param masterDataFieldValueMap the masterDataFieldValueMap to set
	 */
	public void setMasterDataFieldValueMap(Map<String, List<MasterDataEntity>> masterDataFieldValueMap) {
		this.masterDataFieldValueMap = masterDataFieldValueMap;
	}

	/**
	 * @return the masterDataMap
	 */
	public Map<Long, MasterDataEntity> getMasterDataMap() {
		return masterDataMap;
	}

	/**
	 * @param masterDataMap the masterDataMap to set
	 */
	public void setMasterDataMap(Map<Long, MasterDataEntity> masterDataMap) {
		this.masterDataMap = masterDataMap;
	}

	public  List<PicklistResponse> getMasterDataListByFormFieldName(String dataType){
		if (!masterDataFieldValueMap.containsKey(dataType)) {
			throw new ZapierServiceException(HttpStatus.NO_CONTENT.value(), "Master data not available.");
		}
		return masterDataFieldValueMap.get(dataType).stream().map(entity -> {
			return new PicklistResponse(entity.getMasterDataId(), entity.getDataValue());
		}).collect(Collectors.toList());
	}


	public Function<Long, MasterDataEntity> getMasterDataEntityBy = masterDataId -> {
		if (!masterDataMap.containsKey(masterDataId)) {
			throw new ZapierServiceException(HttpStatus.NO_CONTENT.value(), "Master data not available.");
		}
		return masterDataMap.get(masterDataId);
	};

}
